# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/40_biol.ipynb.

# %% auto 0
__all__ = ['isfilteredmatrixpath', 'isadatafile', 'isfilteredmatrixdir', 'isfmatdir', 'isfmat']

# %% ../nbs/40_biol.ipynb 4
import os
from pathlib import Path
from typing import TypeGuard, Union, ForwardRef

# %% ../nbs/40_biol.ipynb 5
from .path import PathLike

# %% ../nbs/40_biol.ipynb 8
def isfilteredmatrixpath(p: PathLike) -> TypeGuard[PathLike]:
    '''Check if the current path is a filtered matrix path'''
    return Path(p).name == 'filtered_matrix'

# %% ../nbs/40_biol.ipynb 9
def isadatapath(p: PathLike) -> TypeGuard[PathLike]:
    '''Check if the current path is an anndatat file path'''
    name = Path(p).name
    return name == 'adata.h5ad' or 'data.h5' in name

def isbarcodespath(p: PathLike) -> TypeGuard[PathLike]:
    '''Check if the current path is a barcodes file path'''
    return Path(p).name == 'barcodes.tsv'

def isfeaturespath(p: PathLike) -> TypeGuard[PathLike]:
    '''Check if the current path is a filtered matrix path'''
    return Path(p).name == 'features.tsv'

def ismatrixpath(p: PathLike) -> TypeGuard[PathLike]:
    '''Check if the current path is a filtered matrix path'''
    return Path(p).name == 'matrix.mtx'

# %% ../nbs/40_biol.ipynb 10
def isbarcodesfile(p: PathLike) -> TypeGuard[PathLike]:
    '''Check if the current path is a barcodes file'''
    return isbarcodespath(p) and Path(p).is_file()

def isfeaturesfile(p: PathLike) -> TypeGuard[PathLike]:
    '''Check if the current path is a features file'''
    return isfeaturespath(p) and Path(p).is_file()

def ismatrixfile(p: PathLike) -> TypeGuard[PathLike]:
    '''Check if the current path is a matrix file'''
    return ismatrixpath(p) and Path(p).is_file()

# %% ../nbs/40_biol.ipynb 11
def isadatafile(p: PathLike) -> TypeGuard[PathLike]:
    '''Check if the current path is an adata file'''
    return isadatapath(p) and Path(p).is_file()

# %% ../nbs/40_biol.ipynb 12
def isfilteredmatrixdir(p: PathLike) -> TypeGuard[PathLike]:
    '''Check if the current path is a filtered matrix path
    
    See Also
    --------
    isfmat : Alias for `isfilteredmatrixdir`.
    isfmatdir : Alias for `isfilteredmatrixdir`.
    '''
    isnamedir = isfilteredmatrixpath(p) and (p := Path(p)).is_dir()
    has_files = isbarcodespath(p / 'barcodes.tsv') and isfeaturespath(p / 'features.tsv') and ismatrixpath(p / 'matrix.mtx')
    return isnamedir or has_files

def isfmatdir(p: PathLike) -> TypeGuard[PathLike]:
    '''Check if the current path is a filtered matrix path
    
    See Also
    --------
    isfilteredmatrixdir : Alias for `isfmatdir`.
    '''
    return isfilteredmatrixdir(p)


def isfmat(p: PathLike) -> TypeGuard[PathLike]:
    '''Check if the current path is a filtered matrix path
    
    See Also
    --------
    isfilteredmatrixdir : Alias for `isfmat`.
    '''
    return isfilteredmatrixdir(p)
